![Alt text](.github/IONOS.CLOUD.BLU.svg?raw=true "Title")

# Go API client for ionoscloud

An enterprise-grade Infrastructure is provided as a Service (IaaS) solution that can be managed through a browser-based \"Data Center Designer\" (DCD) tool or via an easy to use API. 

The API allows you to perform a variety of management tasks such as spinning up additional servers, adding volumes, adjusting networking, and so forth. It is designed to allow users to leverage the same power and flexibility found within the DCD visual tool. Both tools are consistent with their concepts and lend well to making the experience smooth and intuitive.

## Overview
This API client was generated by the [OpenAPI Generator](https://openapi-generator.tech) project.  By using the [OpenAPI-spec](https://www.openapis.org/) from a remote server, you can easily generate an API client.

- API version: 6.0-SDK.1
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.GoClientCodegen

## Installation

Install the following dependencies:

```shell
go get github.com/stretchr/testify/assert
go get golang.org/x/oauth2
go get golang.org/x/net/context
```

Put the package under your project folder and add the following in import:

```golang
import sw "./ionoscloud"
```

To use a proxy, set the environment variable `HTTP_PROXY`:

```golang
os.Setenv("HTTP_PROXY", "http://proxy_name:proxy_port")
```

## Configuration of Server URL

Default configuration comes with `Servers` field that contains server objects as defined in the OpenAPI specification.

### Select Server Configuration

For using other server than the one defined on index 0 set context value `sw.ContextServerIndex` of type `int`.

```golang
ctx := context.WithValue(context.Background(), sw.ContextServerIndex, 1)
```

⚠️ **_Note: To overwrite the api endpoint - `api.ionos.com`, the environment variable `$IONOS_API_URL` can be set, and used with `NewConfigurationFromEnv()` function._**

### Templated Server URL

Templated server URL is formatted using default variables from configuration or from context value `sw.ContextServerVariables` of type `map[string]string`.

```golang
ctx := context.WithValue(context.Background(), sw.ContextServerVariables, map[string]string{
	"basePath": "v2",
})
```

Note, enum values are always validated and all unused variables are silently ignored.

### URLs Configuration per Operation

Each operation can use different server URL defined using `OperationServers` map in the `Configuration`.
An operation is uniquely identified by `"{classname}Service.{nickname}"` string.
Similar rules for overriding default operation server index and variables applies by using `sw.ContextOperationServerIndices` and `sw.ContextOperationServerVariables` context maps.

```
ctx := context.WithValue(context.Background(), sw.ContextOperationServerIndices, map[string]int{
	"{classname}Service.{nickname}": 2,
})
ctx = context.WithValue(context.Background(), sw.ContextOperationServerVariables, map[string]map[string]string{
	"{classname}Service.{nickname}": {
		"port": "8443",
	},
})
```

### Environment Variables

| Environment Variable | Description                                                                                                                                                                                                                    |
|----------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| `IONOS_USERNAME`     | Specify the username used to login, to authenticate against the IONOS Cloud API                                                                                                                                                | 
| `IONOS_PASSWORD`     | Specify the password used to login, to authenticate against the IONOS Cloud API                                                                                                                                                | 
| `IONOS_TOKEN`        | Specify the token used to login, if a token is being used instead of username and password                                                                                                                                     |
| `IONOS_API_URL`      | Specify the API URL. It will overwrite the API endpoint default value `api.ionos.com`. Note: the host URL does not contain the `/cloudapi/v5` path, so it should _not_ be included in the `IONOS_API_URL` environment variable | 

## Documentation for API Endpoints

All URIs are relative to *https://api.ionos.com/cloudapi/v6*
<details >
<summary title="Click to toggle">API Endpoints table</summary>

| Class                     | Method                                                                                                                                                                               | HTTP request                                                                                                           | Description                                                                 |
|---------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------|-----------------------------------------------------------------------------|
| *DefaultApi*              | [**ApiInfoGet**](docs/api/DefaultApi.md#apiinfoget)                                                                                                                                  | **Get** /                                                                                                              | Display API information                                                     |
| *BackupUnitsApi*          | [**BackupunitsDelete**](docs/api/BackupUnitsApi.md#backupunitsdelete)                                                                                                                | **Delete** /backupunits/{backupunitId}                                                                                 | Delete a Backup Unit                                                        |
| *BackupUnitsApi*          | [**BackupunitsFindById**](docs/api/BackupUnitsApi.md#backupunitsfindbyid)                                                                                                            | **Get** /backupunits/{backupunitId}                                                                                    | Returns the specified Backup Unit                                           |
| *BackupUnitsApi*          | [**BackupunitsGet**](docs/api/BackupUnitsApi.md#backupunitsget)                                                                                                                      | **Get** /backupunits                                                                                                   | List Backup Units                                                           |
| *BackupUnitsApi*          | [**BackupunitsPatch**](docs/api/BackupUnitsApi.md#backupunitspatch)                                                                                                                  | **Patch** /backupunits/{backupunitId}                                                                                  | Partially modify a Backup Unit                                              |
| *BackupUnitsApi*          | [**BackupunitsPost**](docs/api/BackupUnitsApi.md#backupunitspost)                                                                                                                    | **Post** /backupunits                                                                                                  | Create a Backup Unit                                                        |
| *BackupUnitsApi*          | [**BackupunitsPut**](docs/api/BackupUnitsApi.md#backupunitsput)                                                                                                                      | **Put** /backupunits/{backupunitId}                                                                                    | Modify a Backup Unit                                                        |
| *BackupUnitsApi*          | [**BackupunitsSsourlGet**](docs/api/BackupUnitsApi.md#backupunitsssourlget)                                                                                                          | **Get** /backupunits/{backupunitId}/ssourl                                                                             | Returns a single signon URL for the specified Backup Unit                   |
| *ContractResourcesApi*    | [**ContractsGet**](docs/api/ContractResourcesApi.md#contractsget)                                                                                                                    | **Get** /contracts                                                                                                     | Retrieve a Contract                                                         |
| *DataCentersApi*          | [**DatacentersDelete**](docs/api/DataCentersApi.md#datacentersdelete)                                                                                                                | **Delete** /datacenters/{datacenterId}                                                                                 | Delete a Data Center                                                        |
| *DataCentersApi*          | [**DatacentersFindById**](docs/api/DataCentersApi.md#datacentersfindbyid)                                                                                                            | **Get** /datacenters/{datacenterId}                                                                                    | Retrieve a Data Center                                                      |
| *DataCentersApi*          | [**DatacentersGet**](docs/api/DataCentersApi.md#datacentersget)                                                                                                                      | **Get** /datacenters                                                                                                   | List Data Centers under your account                                        |
| *DataCentersApi*          | [**DatacentersPatch**](docs/api/DataCentersApi.md#datacenterspatch)                                                                                                                  | **Patch** /datacenters/{datacenterId}                                                                                  | Partially modify a Data Center                                              |
| *DataCentersApi*          | [**DatacentersPost**](docs/api/DataCentersApi.md#datacenterspost)                                                                                                                    | **Post** /datacenters                                                                                                  | Create a Data Center                                                        |
| *DataCentersApi*          | [**DatacentersPut**](docs/api/DataCentersApi.md#datacentersput)                                                                                                                      | **Put** /datacenters/{datacenterId}                                                                                    | Modify a Data Center                                                        |
| *FirewallRulesApi*        | [**DatacentersServersNicsFirewallrulesDelete**](docs/api/FirewallRulesApi.md#datacentersserversnicsfirewallrulesdelete)                                                              | **Delete** /datacenters/{datacenterId}/servers/{serverId}/nics/{nicId}/firewallrules/{firewallruleId}                  | Delete a Firewall Rule                                                      |
| *FirewallRulesApi*        | [**DatacentersServersNicsFirewallrulesFindById**](docs/api/FirewallRulesApi.md#datacentersserversnicsfirewallrulesfindbyid)                                                          | **Get** /datacenters/{datacenterId}/servers/{serverId}/nics/{nicId}/firewallrules/{firewallruleId}                     | Retrieve a Firewall Rule                                                    |
| *FirewallRulesApi*        | [**DatacentersServersNicsFirewallrulesGet**](docs/api/FirewallRulesApi.md#datacentersserversnicsfirewallrulesget)                                                                    | **Get** /datacenters/{datacenterId}/servers/{serverId}/nics/{nicId}/firewallrules                                      | List Firewall Rules                                                         |
| *FirewallRulesApi*        | [**DatacentersServersNicsFirewallrulesPatch**](docs/api/FirewallRulesApi.md#datacentersserversnicsfirewallrulespatch)                                                                | **Patch** /datacenters/{datacenterId}/servers/{serverId}/nics/{nicId}/firewallrules/{firewallruleId}                   | Partially Modify a Firewall Rule                                            |
| *FirewallRulesApi*        | [**DatacentersServersNicsFirewallrulesPost**](docs/api/FirewallRulesApi.md#datacentersserversnicsfirewallrulespost)                                                                  | **Post** /datacenters/{datacenterId}/servers/{serverId}/nics/{nicId}/firewallrules                                     | Create a Firewall Rule                                                      |
| *FirewallRulesApi*        | [**DatacentersServersNicsFirewallrulesPut**](docs/api/FirewallRulesApi.md#datacentersserversnicsfirewallrulesput)                                                                    | **Put** /datacenters/{datacenterId}/servers/{serverId}/nics/{nicId}/firewallrules/{firewallruleId}                     | Modify a Firewall Rule                                                      |
| *FlowLogsApi*             | [**DatacentersServersNicsFlowlogsDelete**](docs/api/FlowLogsApi.md#datacentersserversnicsflowlogsdelete)                                                                             | **Delete** /datacenters/{datacenterId}/servers/{serverId}/nics/{nicId}/flowlogs/{flowlogId}                            | Delete a Flow Log                                                           |
| *FlowLogsApi*             | [**DatacentersServersNicsFlowlogsFindById**](docs/api/FlowLogsApi.md#datacentersserversnicsflowlogsfindbyid)                                                                         | **Get** /datacenters/{datacenterId}/servers/{serverId}/nics/{nicId}/flowlogs/{flowlogId}                               | Retrieve a Flow Log                                                         |
| *FlowLogsApi*             | [**DatacentersServersNicsFlowlogsGet**](docs/api/FlowLogsApi.md#datacentersserversnicsflowlogsget)                                                                                   | **Get** /datacenters/{datacenterId}/servers/{serverId}/nics/{nicId}/flowlogs                                           | List Flow Logs                                                              |
| *FlowLogsApi*             | [**DatacentersServersNicsFlowlogsPatch**](docs/api/FlowLogsApi.md#datacentersserversnicsflowlogspatch)                                                                               | **Patch** /datacenters/{datacenterId}/servers/{serverId}/nics/{nicId}/flowlogs/{flowlogId}                             | Partially update a Flow Log                                                 |
| *FlowLogsApi*             | [**DatacentersServersNicsFlowlogsPost**](docs/api/FlowLogsApi.md#datacentersserversnicsflowlogspost)                                                                                 | **Post** /datacenters/{datacenterId}/servers/{serverId}/nics/{nicId}/flowlogs                                          | Create a Flow Log                                                           |
| *FlowLogsApi*             | [**DatacentersServersNicsFlowlogsPut**](docs/api/FlowLogsApi.md#datacentersserversnicsflowlogsput)                                                                                   | **Put** /datacenters/{datacenterId}/servers/{serverId}/nics/{nicId}/flowlogs/{flowlogId}                               | Modify a Flow Log                                                           |
| *IPBlocksApi*             | [**IpblocksDelete**](docs/api/IPBlocksApi.md#ipblocksdelete)                                                                                                                         | **Delete** /ipblocks/{ipblockId}                                                                                       | Delete IP Block                                                             |
| *IPBlocksApi*             | [**IpblocksFindById**](docs/api/IPBlocksApi.md#ipblocksfindbyid)                                                                                                                     | **Get** /ipblocks/{ipblockId}                                                                                          | Retrieve an IP Block                                                        |
| *IPBlocksApi*             | [**IpblocksGet**](docs/api/IPBlocksApi.md#ipblocksget)                                                                                                                               | **Get** /ipblocks                                                                                                      | List IP Blocks                                                              |
| *IPBlocksApi*             | [**IpblocksPatch**](docs/api/IPBlocksApi.md#ipblockspatch)                                                                                                                           | **Patch** /ipblocks/{ipblockId}                                                                                        | Partially modify IP Block                                                   |
| *IPBlocksApi*             | [**IpblocksPost**](docs/api/IPBlocksApi.md#ipblockspost)                                                                                                                             | **Post** /ipblocks                                                                                                     | Reserve IP Block                                                            |
| *IPBlocksApi*             | [**IpblocksPut**](docs/api/IPBlocksApi.md#ipblocksput)                                                                                                                               | **Put** /ipblocks/{ipblockId}                                                                                          | Modify IP Block                                                             |
| *ImagesApi*               | [**ImagesDelete**](docs/api/ImagesApi.md#imagesdelete)                                                                                                                               | **Delete** /images/{imageId}                                                                                           | Delete an Image                                                             |
| *ImagesApi*               | [**ImagesFindById**](docs/api/ImagesApi.md#imagesfindbyid)                                                                                                                           | **Get** /images/{imageId}                                                                                              | Retrieve an Image                                                           |
| *ImagesApi*               | [**ImagesGet**](docs/api/ImagesApi.md#imagesget)                                                                                                                                     | **Get** /images                                                                                                        | List Images                                                                 |
| *ImagesApi*               | [**ImagesPatch**](docs/api/ImagesApi.md#imagespatch)                                                                                                                                 | **Patch** /images/{imageId}                                                                                            | Partially modify an Image                                                   |
| *ImagesApi*               | [**ImagesPut**](docs/api/ImagesApi.md#imagesput)                                                                                                                                     | **Put** /images/{imageId}                                                                                              | Modify an Image                                                             |
| *KubernetesApi*           | [**K8sDelete**](docs/api/KubernetesApi.md#k8sdelete)                                                                                                                                 | **Delete** /k8s/{k8sClusterId}                                                                                         | Delete Kubernetes Cluster                                                   |
| *KubernetesApi*           | [**K8sFindByClusterId**](docs/api/KubernetesApi.md#k8sfindbyclusterid)                                                                                                               | **Get** /k8s/{k8sClusterId}                                                                                            | Retrieve Kubernetes Cluster                                                 |
| *KubernetesApi*           | [**K8sGet**](docs/api/KubernetesApi.md#k8sget)                                                                                                                                       | **Get** /k8s                                                                                                           | List Kubernetes Clusters                                                    |
| *KubernetesApi*           | [**K8sKubeconfigGet**](docs/api/KubernetesApi.md#k8skubeconfigget)                                                                                                                   | **Get** /k8s/{k8sClusterId}/kubeconfig                                                                                 | Retrieve Kubernetes Configuration File                                      |
| *KubernetesApi*           | [**K8sNodepoolsDelete**](docs/api/KubernetesApi.md#k8snodepoolsdelete)                                                                                                               | **Delete** /k8s/{k8sClusterId}/nodepools/{nodepoolId}                                                                  | Delete Kubernetes Node Pool                                                 |
| *KubernetesApi*           | [**K8sNodepoolsFindById**](docs/api/KubernetesApi.md#k8snodepoolsfindbyid)                                                                                                           | **Get** /k8s/{k8sClusterId}/nodepools/{nodepoolId}                                                                     | Retrieve Kubernetes Node Pool                                               |
| *KubernetesApi*           | [**K8sNodepoolsGet**](docs/api/KubernetesApi.md#k8snodepoolsget)                                                                                                                     | **Get** /k8s/{k8sClusterId}/nodepools                                                                                  | List Kubernetes Node Pools                                                  |
| *KubernetesApi*           | [**K8sNodepoolsNodesDelete**](docs/api/KubernetesApi.md#k8snodepoolsnodesdelete)                                                                                                     | **Delete** /k8s/{k8sClusterId}/nodepools/{nodepoolId}/nodes/{nodeId}                                                   | Delete Kubernetes node                                                      |
| *KubernetesApi*           | [**K8sNodepoolsNodesFindById**](docs/api/KubernetesApi.md#k8snodepoolsnodesfindbyid)                                                                                                 | **Get** /k8s/{k8sClusterId}/nodepools/{nodepoolId}/nodes/{nodeId}                                                      | Retrieve Kubernetes node                                                    |
| *KubernetesApi*           | [**K8sNodepoolsNodesGet**](docs/api/KubernetesApi.md#k8snodepoolsnodesget)                                                                                                           | **Get** /k8s/{k8sClusterId}/nodepools/{nodepoolId}/nodes                                                               | Retrieve Kubernetes nodes.                                                  |
| *KubernetesApi*           | [**K8sNodepoolsNodesReplacePost**](docs/api/KubernetesApi.md#k8snodepoolsnodesreplacepost)                                                                                           | **Post** /k8s/{k8sClusterId}/nodepools/{nodepoolId}/nodes/{nodeId}/replace                                             | Recreate the Kubernetes node                                                |
| *KubernetesApi*           | [**K8sNodepoolsPost**](docs/api/KubernetesApi.md#k8snodepoolspost)                                                                                                                   | **Post** /k8s/{k8sClusterId}/nodepools                                                                                 | Create a Kubernetes Node Pool                                               |
| *KubernetesApi*           | [**K8sNodepoolsPut**](docs/api/KubernetesApi.md#k8snodepoolsput)                                                                                                                     | **Put** /k8s/{k8sClusterId}/nodepools/{nodepoolId}                                                                     | Modify Kubernetes Node Pool                                                 |
| *KubernetesApi*           | [**K8sPost**](docs/api/KubernetesApi.md#k8spost)                                                                                                                                     | **Post** /k8s                                                                                                          | Create Kubernetes Cluster                                                   |
| *KubernetesApi*           | [**K8sPut**](docs/api/KubernetesApi.md#k8sput)                                                                                                                                       | **Put** /k8s/{k8sClusterId}                                                                                            | Modify Kubernetes Cluster                                                   |
| *KubernetesApi*           | [**K8sVersionsDefaultGet**](docs/api/KubernetesApi.md#k8sversionsdefaultget)                                                                                                         | **Get** /k8s/versions/default                                                                                          | Retrieve the current default kubernetes version for clusters and nodepools. |
| *KubernetesApi*           | [**K8sVersionsGet**](docs/api/KubernetesApi.md#k8sversionsget)                                                                                                                       | **Get** /k8s/versions                                                                                                  | Retrieve available Kubernetes versions                                      |
| *LabelsApi*               | [**DatacentersLabelsDelete**](docs/api/LabelsApi.md#datacenterslabelsdelete)                                                                                                         | **Delete** /datacenters/{datacenterId}/labels/{key}                                                                    | Delete a Label from Data Center                                             |
| *LabelsApi*               | [**DatacentersLabelsFindByKey**](docs/api/LabelsApi.md#datacenterslabelsfindbykey)                                                                                                   | **Get** /datacenters/{datacenterId}/labels/{key}                                                                       | Retrieve a Label of Data Center                                             |
| *LabelsApi*               | [**DatacentersLabelsGet**](docs/api/LabelsApi.md#datacenterslabelsget)                                                                                                               | **Get** /datacenters/{datacenterId}/labels                                                                             | List all Data Center Labels                                                 |
| *LabelsApi*               | [**DatacentersLabelsPost**](docs/api/LabelsApi.md#datacenterslabelspost)                                                                                                             | **Post** /datacenters/{datacenterId}/labels                                                                            | Add a Label to Data Center                                                  |
| *LabelsApi*               | [**DatacentersLabelsPut**](docs/api/LabelsApi.md#datacenterslabelsput)                                                                                                               | **Put** /datacenters/{datacenterId}/labels/{key}                                                                       | Modify a Label of Data Center                                               |
| *LabelsApi*               | [**DatacentersServersLabelsDelete**](docs/api/LabelsApi.md#datacentersserverslabelsdelete)                                                                                           | **Delete** /datacenters/{datacenterId}/servers/{serverId}/labels/{key}                                                 | Delete a Label from Server                                                  |
| *LabelsApi*               | [**DatacentersServersLabelsFindByKey**](docs/api/LabelsApi.md#datacentersserverslabelsfindbykey)                                                                                     | **Get** /datacenters/{datacenterId}/servers/{serverId}/labels/{key}                                                    | Retrieve a Label of Server                                                  |
| *LabelsApi*               | [**DatacentersServersLabelsGet**](docs/api/LabelsApi.md#datacentersserverslabelsget)                                                                                                 | **Get** /datacenters/{datacenterId}/servers/{serverId}/labels                                                          | List all Server Labels                                                      |
| *LabelsApi*               | [**DatacentersServersLabelsPost**](docs/api/LabelsApi.md#datacentersserverslabelspost)                                                                                               | **Post** /datacenters/{datacenterId}/servers/{serverId}/labels                                                         | Add a Label to Server                                                       |
| *LabelsApi*               | [**DatacentersServersLabelsPut**](docs/api/LabelsApi.md#datacentersserverslabelsput)                                                                                                 | **Put** /datacenters/{datacenterId}/servers/{serverId}/labels/{key}                                                    | Modify a Label of Server                                                    |
| *LabelsApi*               | [**DatacentersVolumesLabelsDelete**](docs/api/LabelsApi.md#datacentersvolumeslabelsdelete)                                                                                           | **Delete** /datacenters/{datacenterId}/volumes/{volumeId}/labels/{key}                                                 | Delete a Label from Volume                                                  |
| *LabelsApi*               | [**DatacentersVolumesLabelsFindByKey**](docs/api/LabelsApi.md#datacentersvolumeslabelsfindbykey)                                                                                     | **Get** /datacenters/{datacenterId}/volumes/{volumeId}/labels/{key}                                                    | Retrieve a Label of Volume                                                  |
| *LabelsApi*               | [**DatacentersVolumesLabelsGet**](docs/api/LabelsApi.md#datacentersvolumeslabelsget)                                                                                                 | **Get** /datacenters/{datacenterId}/volumes/{volumeId}/labels                                                          | List all Volume Labels                                                      |
| *LabelsApi*               | [**DatacentersVolumesLabelsPost**](docs/api/LabelsApi.md#datacentersvolumeslabelspost)                                                                                               | **Post** /datacenters/{datacenterId}/volumes/{volumeId}/labels                                                         | Add a Label to Volume                                                       |
| *LabelsApi*               | [**DatacentersVolumesLabelsPut**](docs/api/LabelsApi.md#datacentersvolumeslabelsput)                                                                                                 | **Put** /datacenters/{datacenterId}/volumes/{volumeId}/labels/{key}                                                    | Modify a Label of Volume                                                    |
| *LabelsApi*               | [**IpblocksLabelsDelete**](docs/api/LabelsApi.md#ipblockslabelsdelete)                                                                                                               | **Delete** /ipblocks/{ipblockId}/labels/{key}                                                                          | Delete a Label from IP Block                                                |
| *LabelsApi*               | [**IpblocksLabelsFindByKey**](docs/api/LabelsApi.md#ipblockslabelsfindbykey)                                                                                                         | **Get** /ipblocks/{ipblockId}/labels/{key}                                                                             | Retrieve a Label of IP Block                                                |
| *LabelsApi*               | [**IpblocksLabelsGet**](docs/api/LabelsApi.md#ipblockslabelsget)                                                                                                                     | **Get** /ipblocks/{ipblockId}/labels                                                                                   | List all Ip Block Labels                                                    |
| *LabelsApi*               | [**IpblocksLabelsPost**](docs/api/LabelsApi.md#ipblockslabelspost)                                                                                                                   | **Post** /ipblocks/{ipblockId}/labels                                                                                  | Add a Label to IP Block                                                     |
| *LabelsApi*               | [**IpblocksLabelsPut**](docs/api/LabelsApi.md#ipblockslabelsput)                                                                                                                     | **Put** /ipblocks/{ipblockId}/labels/{key}                                                                             | Modify a Label of IP Block                                                  |
| *LabelsApi*               | [**LabelsFindByUrn**](docs/api/LabelsApi.md#labelsfindbyurn)                                                                                                                         | **Get** /labels/{labelurn}                                                                                             | Returns the label by its URN.                                               |
| *LabelsApi*               | [**LabelsGet**](docs/api/LabelsApi.md#labelsget)                                                                                                                                     | **Get** /labels                                                                                                        | List Labels                                                                 |
| *LabelsApi*               | [**SnapshotsLabelsDelete**](docs/api/LabelsApi.md#snapshotslabelsdelete)                                                                                                             | **Delete** /snapshots/{snapshotId}/labels/{key}                                                                        | Delete a Label from Snapshot                                                |
| *LabelsApi*               | [**SnapshotsLabelsFindByKey**](docs/api/LabelsApi.md#snapshotslabelsfindbykey)                                                                                                       | **Get** /snapshots/{snapshotId}/labels/{key}                                                                           | Retrieve a Label of Snapshot                                                |
| *LabelsApi*               | [**SnapshotsLabelsGet**](docs/api/LabelsApi.md#snapshotslabelsget)                                                                                                                   | **Get** /snapshots/{snapshotId}/labels                                                                                 | List all Snapshot Labels                                                    |
| *LabelsApi*               | [**SnapshotsLabelsPost**](docs/api/LabelsApi.md#snapshotslabelspost)                                                                                                                 | **Post** /snapshots/{snapshotId}/labels                                                                                | Add a Label to Snapshot                                                     |
| *LabelsApi*               | [**SnapshotsLabelsPut**](docs/api/LabelsApi.md#snapshotslabelsput)                                                                                                                   | **Put** /snapshots/{snapshotId}/labels/{key}                                                                           | Modify a Label of Snapshot                                                  |
| *LansApi*                 | [**DatacentersLansDelete**](docs/api/LANsApi.md#datacenterslansdelete)                                                                                                               | **Delete** /datacenters/{datacenterId}/lans/{lanId}                                                                    | Delete a Lan.                                                               |
| *LansApi*                 | [**DatacentersLansFindById**](docs/api/LANsApi.md#datacenterslansfindbyid)                                                                                                           | **Get** /datacenters/{datacenterId}/lans/{lanId}                                                                       | Retrieve a Lan                                                              |
| *LansApi*                 | [**DatacentersLansGet**](docs/api/LANsApi.md#datacenterslansget)                                                                                                                     | **Get** /datacenters/{datacenterId}/lans                                                                               | List Lans                                                                   |
| *LansApi*                 | [**DatacentersLansNicsFindById**](docs/api/LANsApi.md#datacenterslansnicsfindbyid)                                                                                                   | **Get** /datacenters/{datacenterId}/lans/{lanId}/nics/{nicId}                                                          | Retrieve a nic attached to lan                                              |
| *LansApi*                 | [**DatacentersLansNicsGet**](docs/api/LANsApi.md#datacenterslansnicsget)                                                                                                             | **Get** /datacenters/{datacenterId}/lans/{lanId}/nics                                                                  | List Lan Members                                                            |
| *LansApi*                 | [**DatacentersLansNicsPost**](docs/api/LANsApi.md#datacenterslansnicspost)                                                                                                           | **Post** /datacenters/{datacenterId}/lans/{lanId}/nics                                                                 | Attach a nic                                                                |
| *LansApi*                 | [**DatacentersLansPatch**](docs/api/LANsApi.md#datacenterslanspatch)                                                                                                                 | **Patch** /datacenters/{datacenterId}/lans/{lanId}                                                                     | Partially modify a Lan                                                      |
| *LansApi*                 | [**DatacentersLansPost**](docs/api/LANsApi.md#datacenterslanspost)                                                                                                                   | **Post** /datacenters/{datacenterId}/lans                                                                              | Create a Lan                                                                |
| *LansApi*                 | [**DatacentersLansPut**](docs/api/LANsApi.md#datacenterslansput)                                                                                                                     | **Put** /datacenters/{datacenterId}/lans/{lanId}                                                                       | Modify a Lan                                                                |
| *LoadBalancersApi*        | [**DatacentersLoadbalancersBalancednicsDelete**](docs/api/LoadBalancersApi.md#datacentersloadbalancersbalancednicsdelete)                                                            | **Delete** /datacenters/{datacenterId}/loadbalancers/{loadbalancerId}/balancednics/{nicId}                             | Detach a nic from loadbalancer                                              |
| *LoadBalancersApi*        | [**DatacentersLoadbalancersBalancednicsFindByNicId**](docs/api/LoadBalancersApi.md#datacentersloadbalancersbalancednicsfindbynicid)                                                  | **Get** /datacenters/{datacenterId}/loadbalancers/{loadbalancerId}/balancednics/{nicId}                                | Retrieve a network interface attached to Load Balancer                      |
| *LoadBalancersApi*        | [**DatacentersLoadbalancersBalancednicsGet**](docs/api/LoadBalancersApi.md#datacentersloadbalancersbalancednicsget)                                                                  | **Get** /datacenters/{datacenterId}/loadbalancers/{loadbalancerId}/balancednics                                        | List Load Balancer balaced NICs                                             |
| *LoadBalancersApi*        | [**DatacentersLoadbalancersBalancednicsPost**](docs/api/LoadBalancersApi.md#datacentersloadbalancersbalancednicspost)                                                                | **Post** /datacenters/{datacenterId}/loadbalancers/{loadbalancerId}/balancednics                                       | Attach a nic to Load Balancer                                               |
| *LoadBalancersApi*        | [**DatacentersLoadbalancersDelete**](docs/api/LoadBalancersApi.md#datacentersloadbalancersdelete)                                                                                    | **Delete** /datacenters/{datacenterId}/loadbalancers/{loadbalancerId}                                                  | Delete a Loadbalancer.                                                      |
| *LoadBalancersApi*        | [**DatacentersLoadbalancersFindById**](docs/api/LoadBalancersApi.md#datacentersloadbalancersfindbyid)                                                                                | **Get** /datacenters/{datacenterId}/loadbalancers/{loadbalancerId}                                                     | Retrieve a loadbalancer                                                     |
| *LoadBalancersApi*        | [**DatacentersLoadbalancersGet**](docs/api/LoadBalancersApi.md#datacentersloadbalancersget)                                                                                          | **Get** /datacenters/{datacenterId}/loadbalancers                                                                      | List Load Balancers                                                         |
| *LoadBalancersApi*        | [**DatacentersLoadbalancersPatch**](docs/api/LoadBalancersApi.md#datacentersloadbalancerspatch)                                                                                      | **Patch** /datacenters/{datacenterId}/loadbalancers/{loadbalancerId}                                                   | Partially modify a Loadbalancer                                             |
| *LoadBalancersApi*        | [**DatacentersLoadbalancersPost**](docs/api/LoadBalancersApi.md#datacentersloadbalancerspost)                                                                                        | **Post** /datacenters/{datacenterId}/loadbalancers                                                                     | Create a Load Balancer                                                      |
| *LoadBalancersApi*        | [**DatacentersLoadbalancersPut**](docs/api/LoadBalancersApi.md#datacentersloadbalancersput)                                                                                          | **Put** /datacenters/{datacenterId}/loadbalancers/{loadbalancerId}                                                     | Modify a Load Balancer                                                      |
| *LocationsApi*            | [**LocationsFindByRegionId**](docs/api/LocationsApi.md#locationsfindbyregionid)                                                                                                      | **Get** /locations/{regionId}                                                                                          | List Locations within a region                                              |
| *LocationsApi*            | [**LocationsFindByRegionIdAndId**](docs/api/LocationsApi.md#locationsfindbyregionidandid)                                                                                            | **Get** /locations/{regionId}/{locationId}                                                                             | Retrieve a Location                                                         |
| *LocationsApi*            | [**LocationsGet**](docs/api/LocationsApi.md#locationsget)                                                                                                                            | **Get** /locations                                                                                                     | List Locations                                                              |
| *NATGatewaysApi*          | [**DatacentersNatgatewaysDelete**](docs/api/NATGatewaysApi.md#datacentersnatgatewaysdelete)                                                                                          | **Delete** /datacenters/{datacenterId}/natgateways/{natGatewayId}                                                      | Remove a NAT gateway                                                        |
| *NATGatewaysApi*          | [**DatacentersNatgatewaysFindByNatGatewayId**](docs/api/NATGatewaysApi.md#datacentersnatgatewaysfindbynatgatewayid)                                                                  | **Get** /datacenters/{datacenterId}/natgateways/{natGatewayId}                                                         | Retrieve a NAT gateway                                                      |
| *NATGatewaysApi*          | [**DatacentersNatgatewaysFlowlogsDelete**](docs/api/NATGatewaysApi.md#datacentersnatgatewaysflowlogsdelete)                                                                          | **Delete** /datacenters/{datacenterId}/natgateways/{natGatewayId}/flowlogs/{flowLogId}                                 | Remove Flow Log from NAT Gateway                                            |
| *NATGatewaysApi*          | [**DatacentersNatgatewaysFlowlogsFindByFlowLogId**](docs/api/NATGatewaysApi.md#datacentersnatgatewaysflowlogsfindbyflowlogid)                                                        | **Get** /datacenters/{datacenterId}/natgateways/{natGatewayId}/flowlogs/{flowLogId}                                    | Retrieve a Flow Log of the NAT Gateway                                      |
| *NATGatewaysApi*          | [**DatacentersNatgatewaysFlowlogsGet**](docs/api/NATGatewaysApi.md#datacentersnatgatewaysflowlogsget)                                                                                | **Get** /datacenters/{datacenterId}/natgateways/{natGatewayId}/flowlogs                                                | List NAT Gateway Flow Logs                                                  |
| *NATGatewaysApi*          | [**DatacentersNatgatewaysFlowlogsPatch**](docs/api/NATGatewaysApi.md#datacentersnatgatewaysflowlogspatch)                                                                            | **Patch** /datacenters/{datacenterId}/natgateways/{natGatewayId}/flowlogs/{flowLogId}                                  | Partially modify a Flow Log of the NAT Gateway                              |
| *NATGatewaysApi*          | [**DatacentersNatgatewaysFlowlogsPost**](docs/api/NATGatewaysApi.md#datacentersnatgatewaysflowlogspost)                                                                              | **Post** /datacenters/{datacenterId}/natgateways/{natGatewayId}/flowlogs                                               | Add a NAT Gateways Flow Log                                                 |
| *NATGatewaysApi*          | [**DatacentersNatgatewaysFlowlogsPut**](docs/api/NATGatewaysApi.md#datacentersnatgatewaysflowlogsput)                                                                                | **Put** /datacenters/{datacenterId}/natgateways/{natGatewayId}/flowlogs/{flowLogId}                                    | Modify a Flow Log of the NAT Gateway                                        |
| *NATGatewaysApi*          | [**DatacentersNatgatewaysGet**](docs/api/NATGatewaysApi.md#datacentersnatgatewaysget)                                                                                                | **Get** /datacenters/{datacenterId}/natgateways                                                                        | List NAT Gateways                                                           |
| *NATGatewaysApi*          | [**DatacentersNatgatewaysPatch**](docs/api/NATGatewaysApi.md#datacentersnatgatewayspatch)                                                                                            | **Patch** /datacenters/{datacenterId}/natgateways/{natGatewayId}                                                       | Partially update a NAT gateway                                              |
| *NATGatewaysApi*          | [**DatacentersNatgatewaysPost**](docs/api/NATGatewaysApi.md#datacentersnatgatewayspost)                                                                                              | **Post** /datacenters/{datacenterId}/natgateways                                                                       | Create a NAT Gateway                                                        |
| *NATGatewaysApi*          | [**DatacentersNatgatewaysPut**](docs/api/NATGatewaysApi.md#datacentersnatgatewaysput)                                                                                                | **Put** /datacenters/{datacenterId}/natgateways/{natGatewayId}                                                         | Update a NAT gateway                                                        |
| *NATGatewaysApi*          | [**DatacentersNatgatewaysRulesDelete**](docs/api/NATGatewaysApi.md#datacentersnatgatewaysrulesdelete)                                                                                | **Delete** /datacenters/{datacenterId}/natgateways/{natGatewayId}/rules/{natGatewayRuleId}                             | Remove rule from NAT Gateway                                                |
| *NATGatewaysApi*          | [**DatacentersNatgatewaysRulesFindByNatGatewayRuleId**](docs/api/NATGatewaysApi.md#datacentersnatgatewaysrulesfindbynatgatewayruleid)                                                | **Get** /datacenters/{datacenterId}/natgateways/{natGatewayId}/rules/{natGatewayRuleId}                                | Retrieve a NAT Gateway Rule                                                 |
| *NATGatewaysApi*          | [**DatacentersNatgatewaysRulesGet**](docs/api/NATGatewaysApi.md#datacentersnatgatewaysrulesget)                                                                                      | **Get** /datacenters/{datacenterId}/natgateways/{natGatewayId}/rules                                                   | List NAT Gateways Rules                                                     |
| *NATGatewaysApi*          | [**DatacentersNatgatewaysRulesPatch**](docs/api/NATGatewaysApi.md#datacentersnatgatewaysrulespatch)                                                                                  | **Patch** /datacenters/{datacenterId}/natgateways/{natGatewayId}/rules/{natGatewayRuleId}                              | Partially modify a rule of the NAT gateway                                  |
| *NATGatewaysApi*          | [**DatacentersNatgatewaysRulesPost**](docs/api/NATGatewaysApi.md#datacentersnatgatewaysrulespost)                                                                                    | **Post** /datacenters/{datacenterId}/natgateways/{natGatewayId}/rules                                                  | Create a NAT Gateway Rule                                                   |
| *NATGatewaysApi*          | [**DatacentersNatgatewaysRulesPut**](docs/api/NATGatewaysApi.md#datacentersnatgatewaysrulesput)                                                                                      | **Put** /datacenters/{datacenterId}/natgateways/{natGatewayId}/rules/{natGatewayRuleId}                                | Modify a rule of the NAT gateway                                            |
| *NetworkInterfacesApi*    | [**DatacentersServersNicsDelete**](docs/api/NetworkInterfacesApi.md#datacentersserversnicsdelete)                                                                                    | **Delete** /datacenters/{datacenterId}/servers/{serverId}/nics/{nicId}                                                 | Delete a Network Interface                                                  |
| *NetworkInterfacesApi*    | [**DatacentersServersNicsFindById**](docs/api/NetworkInterfacesApi.md#datacentersserversnicsfindbyid)                                                                                | **Get** /datacenters/{datacenterId}/servers/{serverId}/nics/{nicId}                                                    | Retrieve a Network Interface                                                |
| *NetworkInterfacesApi*    | [**DatacentersServersNicsGet**](docs/api/NetworkInterfacesApi.md#datacentersserversnicsget)                                                                                          | **Get** /datacenters/{datacenterId}/servers/{serverId}/nics                                                            | List Network Interfaces                                                     |
| *NetworkInterfacesApi*    | [**DatacentersServersNicsPatch**](docs/api/NetworkInterfacesApi.md#datacentersserversnicspatch)                                                                                      | **Patch** /datacenters/{datacenterId}/servers/{serverId}/nics/{nicId}                                                  | Partially Modify a Network Interface                                        |
| *NetworkInterfacesApi*    | [**DatacentersServersNicsPost**](docs/api/NetworkInterfacesApi.md#datacentersserversnicspost)                                                                                        | **Post** /datacenters/{datacenterId}/servers/{serverId}/nics                                                           | Create a Network Interface                                                  |
| *NetworkInterfacesApi*    | [**DatacentersServersNicsPut**](docs/api/NetworkInterfacesApi.md#datacentersserversnicsput)                                                                                          | **Put** /datacenters/{datacenterId}/servers/{serverId}/nics/{nicId}                                                    | Modify a Network Interface                                                  |
| *NetworkLoadBalancersApi* | [**DatacentersNetworkloadbalancersDelete**](docs/api/NetworkLoadBalancersApi.md#datacentersnetworkloadbalancersdelete)                                                               | **Delete** /datacenters/{datacenterId}/networkloadbalancers/{networkLoadBalancerId}                                    | Remove an Network Load Balancer                                             |
| *NetworkLoadBalancersApi* | [**DatacentersNetworkloadbalancersFindByNetworkLoadBalancerId**](docs/api/NetworkLoadBalancersApi.md#datacentersnetworkloadbalancersfindbynetworkloadbalancerid)                     | **Get** /datacenters/{datacenterId}/networkloadbalancers/{networkLoadBalancerId}                                       | Retrieve an Network Load Balancer                                           |
| *NetworkLoadBalancersApi* | [**DatacentersNetworkloadbalancersFlowlogsDelete**](docs/api/NetworkLoadBalancersApi.md#datacentersnetworkloadbalancersflowlogsdelete)                                               | **Delete** /datacenters/{datacenterId}/networkloadbalancers/{networkLoadBalancerId}/flowlogs/{flowLogId}               | Remove Flow Log from Network Load Balancer                                  |
| *NetworkLoadBalancersApi* | [**DatacentersNetworkloadbalancersFlowlogsFindByFlowLogId**](docs/api/NetworkLoadBalancersApi.md#datacentersnetworkloadbalancersflowlogsfindbyflowlogid)                             | **Get** /datacenters/{datacenterId}/networkloadbalancers/{networkLoadBalancerId}/flowlogs/{flowLogId}                  | Retrieve a Flow Log of the Network Load Balancer                            |
| *NetworkLoadBalancersApi* | [**DatacentersNetworkloadbalancersFlowlogsGet**](docs/api/NetworkLoadBalancersApi.md#datacentersnetworkloadbalancersflowlogsget)                                                     | **Get** /datacenters/{datacenterId}/networkloadbalancers/{networkLoadBalancerId}/flowlogs                              | List Network Load Balancer Flow Logs                                        |
| *NetworkLoadBalancersApi* | [**DatacentersNetworkloadbalancersFlowlogsPatch**](docs/api/NetworkLoadBalancersApi.md#datacentersnetworkloadbalancersflowlogspatch)                                                 | **Patch** /datacenters/{datacenterId}/networkloadbalancers/{networkLoadBalancerId}/flowlogs/{flowLogId}                | Partially modify a Flow Log of the Network Load Balancer                    |
| *NetworkLoadBalancersApi* | [**DatacentersNetworkloadbalancersFlowlogsPost**](docs/api/NetworkLoadBalancersApi.md#datacentersnetworkloadbalancersflowlogspost)                                                   | **Post** /datacenters/{datacenterId}/networkloadbalancers/{networkLoadBalancerId}/flowlogs                             | Add a Network Load Balancer Flow Log                                        |
| *NetworkLoadBalancersApi* | [**DatacentersNetworkloadbalancersFlowlogsPut**](docs/api/NetworkLoadBalancersApi.md#datacentersnetworkloadbalancersflowlogsput)                                                     | **Put** /datacenters/{datacenterId}/networkloadbalancers/{networkLoadBalancerId}/flowlogs/{flowLogId}                  | Modify a Flow Log of the Network Load Balancer                              |
| *NetworkLoadBalancersApi* | [**DatacentersNetworkloadbalancersForwardingrulesDelete**](docs/api/NetworkLoadBalancersApi.md#datacentersnetworkloadbalancersforwardingrulesdelete)                                 | **Delete** /datacenters/{datacenterId}/networkloadbalancers/{networkLoadBalancerId}/forwardingrules/{forwardingRuleId} | Remove Forwarding Rule from Network Load Balancer                           |
| *NetworkLoadBalancersApi* | [**DatacentersNetworkloadbalancersForwardingrulesFindByForwardingRuleId**](docs/api/NetworkLoadBalancersApi.md#datacentersnetworkloadbalancersforwardingrulesfindbyforwardingruleid) | **Get** /datacenters/{datacenterId}/networkloadbalancers/{networkLoadBalancerId}/forwardingrules/{forwardingRuleId}    | Retrieve a Forwarding Rule of the Network Load Balancer                     |
| *NetworkLoadBalancersApi* | [**DatacentersNetworkloadbalancersForwardingrulesGet**](docs/api/NetworkLoadBalancersApi.md#datacentersnetworkloadbalancersforwardingrulesget)                                       | **Get** /datacenters/{datacenterId}/networkloadbalancers/{networkLoadBalancerId}/forwardingrules                       | List Network Load Balancer Forwarding Rules                                 |
| *NetworkLoadBalancersApi* | [**DatacentersNetworkloadbalancersForwardingrulesPatch**](docs/api/NetworkLoadBalancersApi.md#datacentersnetworkloadbalancersforwardingrulespatch)                                   | **Patch** /datacenters/{datacenterId}/networkloadbalancers/{networkLoadBalancerId}/forwardingrules/{forwardingRuleId}  | Partially modify a forwarding rule of the Network Load Balancer             |
| *NetworkLoadBalancersApi* | [**DatacentersNetworkloadbalancersForwardingrulesPost**](docs/api/NetworkLoadBalancersApi.md#datacentersnetworkloadbalancersforwardingrulespost)                                     | **Post** /datacenters/{datacenterId}/networkloadbalancers/{networkLoadBalancerId}/forwardingrules                      | Add a Network Load Balancer Forwarding Rule                                 |
| *NetworkLoadBalancersApi* | [**DatacentersNetworkloadbalancersForwardingrulesPut**](docs/api/NetworkLoadBalancersApi.md#datacentersnetworkloadbalancersforwardingrulesput)                                       | **Put** /datacenters/{datacenterId}/networkloadbalancers/{networkLoadBalancerId}/forwardingrules/{forwardingRuleId}    | Modify a forwarding rule of the Network Load Balancer                       |
| *NetworkLoadBalancersApi* | [**DatacentersNetworkloadbalancersGet**](docs/api/NetworkLoadBalancersApi.md#datacentersnetworkloadbalancersget)                                                                     | **Get** /datacenters/{datacenterId}/networkloadbalancers                                                               | List Network Load Balancers                                                 |
| *NetworkLoadBalancersApi* | [**DatacentersNetworkloadbalancersPatch**](docs/api/NetworkLoadBalancersApi.md#datacentersnetworkloadbalancerspatch)                                                                 | **Patch** /datacenters/{datacenterId}/networkloadbalancers/{networkLoadBalancerId}                                     | Partially update an Network Load Balancer                                   |
| *NetworkLoadBalancersApi* | [**DatacentersNetworkloadbalancersPost**](docs/api/NetworkLoadBalancersApi.md#datacentersnetworkloadbalancerspost)                                                                   | **Post** /datacenters/{datacenterId}/networkloadbalancers                                                              | Create an Network Load Balancer                                             |
| *NetworkLoadBalancersApi* | [**DatacentersNetworkloadbalancersPut**](docs/api/NetworkLoadBalancersApi.md#datacentersnetworkloadbalancersput)                                                                     | **Put** /datacenters/{datacenterId}/networkloadbalancers/{networkLoadBalancerId}                                       | Update an Network Load Balancer                                             |
| *PrivateCrossConnectsApi* | [**PccsDelete**](docs/api/PrivateCrossConnectsApi.md#pccsdelete)                                                                                                                     | **Delete** /pccs/{pccId}                                                                                               | Delete a Private Cross-Connect                                              |
| *PrivateCrossConnectsApi* | [**PccsFindById**](docs/api/PrivateCrossConnectsApi.md#pccsfindbyid)                                                                                                                 | **Get** /pccs/{pccId}                                                                                                  | Retrieve a Private Cross-Connect                                            |
| *PrivateCrossConnectsApi* | [**PccsGet**](docs/api/PrivateCrossConnectsApi.md#pccsget)                                                                                                                           | **Get** /pccs                                                                                                          | List Private Cross-Connects                                                 |
| *PrivateCrossConnectsApi* | [**PccsPatch**](docs/api/PrivateCrossConnectsApi.md#pccspatch)                                                                                                                       | **Patch** /pccs/{pccId}                                                                                                | Partially Modify a Private Cross-Connect                                    |
| *PrivateCrossConnectsApi* | [**PccsPost**](docs/api/PrivateCrossConnectsApi.md#pccspost)                                                                                                                         | **Post** /pccs                                                                                                         | Create a Private Cross-Connect                                              |
| *RequestsApi*             | [**RequestsFindById**](docs/api/RequestsApi.md#requestsfindbyid)                                                                                                                     | **Get** /requests/{requestId}                                                                                          | Retrieve a Request                                                          |
| *RequestsApi*             | [**RequestsGet**](docs/api/RequestsApi.md#requestsget)                                                                                                                               | **Get** /requests                                                                                                      | List Requests                                                               |
| *RequestsApi*             | [**RequestsStatusGet**](docs/api/RequestsApi.md#requestsstatusget)                                                                                                                   | **Get** /requests/{requestId}/status                                                                                   | Retrieve Request Status                                                     |
| *ServersApi*              | [**DatacentersServersCdromsDelete**](docs/api/ServersApi.md#datacentersserverscdromsdelete)                                                                                          | **Delete** /datacenters/{datacenterId}/servers/{serverId}/cdroms/{cdromId}                                             | Detach a CD-ROM                                                             |
| *ServersApi*              | [**DatacentersServersCdromsFindById**](docs/api/ServersApi.md#datacentersserverscdromsfindbyid)                                                                                      | **Get** /datacenters/{datacenterId}/servers/{serverId}/cdroms/{cdromId}                                                | Retrieve an attached CD-ROM                                                 |
| *ServersApi*              | [**DatacentersServersCdromsGet**](docs/api/ServersApi.md#datacentersserverscdromsget)                                                                                                | **Get** /datacenters/{datacenterId}/servers/{serverId}/cdroms                                                          | List attached CD-ROMs                                                       |
| *ServersApi*              | [**DatacentersServersCdromsPost**](docs/api/ServersApi.md#datacentersserverscdromspost)                                                                                              | **Post** /datacenters/{datacenterId}/servers/{serverId}/cdroms                                                         | Attach a CD-ROM                                                             |
| *ServersApi*              | [**DatacentersServersDelete**](docs/api/ServersApi.md#datacentersserversdelete)                                                                                                      | **Delete** /datacenters/{datacenterId}/servers/{serverId}                                                              | Delete a Server                                                             |
| *ServersApi*              | [**DatacentersServersFindById**](docs/api/ServersApi.md#datacentersserversfindbyid)                                                                                                  | **Get** /datacenters/{datacenterId}/servers/{serverId}                                                                 | Retrieve a Server                                                           |
| *ServersApi*              | [**DatacentersServersGet**](docs/api/ServersApi.md#datacentersserversget)                                                                                                            | **Get** /datacenters/{datacenterId}/servers                                                                            | List Servers                                                                |
| *ServersApi*              | [**DatacentersServersPatch**](docs/api/ServersApi.md#datacentersserverspatch)                                                                                                        | **Patch** /datacenters/{datacenterId}/servers/{serverId}                                                               | Partially modify a Server                                                   |
| *ServersApi*              | [**DatacentersServersPost**](docs/api/ServersApi.md#datacentersserverspost)                                                                                                          | **Post** /datacenters/{datacenterId}/servers                                                                           | Create a Server                                                             |
| *ServersApi*              | [**DatacentersServersPut**](docs/api/ServersApi.md#datacentersserversput)                                                                                                            | **Put** /datacenters/{datacenterId}/servers/{serverId}                                                                 | Modify a Server                                                             |
| *ServersApi*              | [**DatacentersServersRebootPost**](docs/api/ServersApi.md#datacentersserversrebootpost)                                                                                              | **Post** /datacenters/{datacenterId}/servers/{serverId}/reboot                                                         | Reboot a Server                                                             |
| *ServersApi*              | [**DatacentersServersRemoteConsoleGet**](docs/api/ServersApi.md#datacentersserversremoteconsoleget)                                                                                  | **Get** /datacenters/{datacenterId}/servers/{serverId}/remoteconsole                                                   | Get the server remote console link                                          |
| *ServersApi*              | [**DatacentersServersResumePost**](docs/api/ServersApi.md#datacentersserversresumepost)                                                                                              | **Post** /datacenters/{datacenterId}/servers/{serverId}/resume                                                         | Resume a Cube Server                                                        |
| *ServersApi*              | [**DatacentersServersStartPost**](docs/api/ServersApi.md#datacentersserversstartpost)                                                                                                | **Post** /datacenters/{datacenterId}/servers/{serverId}/start                                                          | Start a Server                                                              |
| *ServersApi*              | [**DatacentersServersStopPost**](docs/api/ServersApi.md#datacentersserversstoppost)                                                                                                  | **Post** /datacenters/{datacenterId}/servers/{serverId}/stop                                                           | Stop a Server                                                               |
| *ServersApi*              | [**DatacentersServersSuspendPost**](docs/api/ServersApi.md#datacentersserverssuspendpost)                                                                                            | **Post** /datacenters/{datacenterId}/servers/{serverId}/suspend                                                        | Suspend a Cube Server                                                       |
| *ServersApi*              | [**DatacentersServersTokenGet**](docs/api/ServersApi.md#datacentersserverstokenget)                                                                                                  | **Get** /datacenters/{datacenterId}/servers/{serverId}/token                                                           | Get the server&#39;s jwToken                                                |
| *ServersApi*              | [**DatacentersServersUpgradePost**](docs/api/ServersApi.md#datacentersserversupgradepost)                                                                                            | **Post** /datacenters/{datacenterId}/servers/{serverId}/upgrade                                                        | Upgrade a Server                                                            |
| *ServersApi*              | [**DatacentersServersVolumesDelete**](docs/api/ServersApi.md#datacentersserversvolumesdelete)                                                                                        | **Delete** /datacenters/{datacenterId}/servers/{serverId}/volumes/{volumeId}                                           | Detach a volume                                                             |
| *ServersApi*              | [**DatacentersServersVolumesFindById**](docs/api/ServersApi.md#datacentersserversvolumesfindbyid)                                                                                    | **Get** /datacenters/{datacenterId}/servers/{serverId}/volumes/{volumeId}                                              | Retrieve an attached volume                                                 |
| *ServersApi*              | [**DatacentersServersVolumesGet**](docs/api/ServersApi.md#datacentersserversvolumesget)                                                                                              | **Get** /datacenters/{datacenterId}/servers/{serverId}/volumes                                                         | List Attached Volumes                                                       |
| *ServersApi*              | [**DatacentersServersVolumesPost**](docs/api/ServersApi.md#datacentersserversvolumespost)                                                                                            | **Post** /datacenters/{datacenterId}/servers/{serverId}/volumes                                                        | Attach a volume                                                             |
| *SnapshotsApi*            | [**SnapshotsDelete**](docs/api/SnapshotsApi.md#snapshotsdelete)                                                                                                                      | **Delete** /snapshots/{snapshotId}                                                                                     | Delete a Snapshot                                                           |
| *SnapshotsApi*            | [**SnapshotsFindById**](docs/api/SnapshotsApi.md#snapshotsfindbyid)                                                                                                                  | **Get** /snapshots/{snapshotId}                                                                                        | Retrieve a Snapshot by its uuid.                                            |
| *SnapshotsApi*            | [**SnapshotsGet**](docs/api/SnapshotsApi.md#snapshotsget)                                                                                                                            | **Get** /snapshots                                                                                                     | List Snapshots                                                              |
| *SnapshotsApi*            | [**SnapshotsPatch**](docs/api/SnapshotsApi.md#snapshotspatch)                                                                                                                        | **Patch** /snapshots/{snapshotId}                                                                                      | Partially modify a Snapshot                                                 |
| *SnapshotsApi*            | [**SnapshotsPut**](docs/api/SnapshotsApi.md#snapshotsput)                                                                                                                            | **Put** /snapshots/{snapshotId}                                                                                        | Modify a Snapshot                                                           |
| *TemplatesApi*            | [**TemplatesFindById**](docs/api/TemplatesApi.md#templatesfindbyid)                                                                                                                  | **Get** /templates/{templateId}                                                                                        | Retrieve an available template                                              |
| *TemplatesApi*            | [**TemplatesGet**](docs/api/TemplatesApi.md#templatesget)                                                                                                                            | **Get** /templates                                                                                                     | List Templates                                                              |
| *UserManagementApi*       | [**UmGroupsDelete**](docs/api/UserManagementApi.md#umgroupsdelete)                                                                                                                   | **Delete** /um/groups/{groupId}                                                                                        | Delete a Group                                                              |
| *UserManagementApi*       | [**UmGroupsFindById**](docs/api/UserManagementApi.md#umgroupsfindbyid)                                                                                                               | **Get** /um/groups/{groupId}                                                                                           | Retrieve a Group                                                            |
| *UserManagementApi*       | [**UmGroupsGet**](docs/api/UserManagementApi.md#umgroupsget)                                                                                                                         | **Get** /um/groups                                                                                                     | List All Groups.                                                            |
| *UserManagementApi*       | [**UmGroupsPost**](docs/api/UserManagementApi.md#umgroupspost)                                                                                                                       | **Post** /um/groups                                                                                                    | Create a Group                                                              |
| *UserManagementApi*       | [**UmGroupsPut**](docs/api/UserManagementApi.md#umgroupsput)                                                                                                                         | **Put** /um/groups/{groupId}                                                                                           | Modify a group                                                              |
| *UserManagementApi*       | [**UmGroupsResourcesGet**](docs/api/UserManagementApi.md#umgroupsresourcesget)                                                                                                       | **Get** /um/groups/{groupId}/resources                                                                                 | Retrieve resources assigned to a group                                      |
| *UserManagementApi*       | [**UmGroupsSharesDelete**](docs/api/UserManagementApi.md#umgroupssharesdelete)                                                                                                       | **Delete** /um/groups/{groupId}/shares/{resourceId}                                                                    | Remove a resource from a group                                              |
| *UserManagementApi*       | [**UmGroupsSharesFindByResourceId**](docs/api/UserManagementApi.md#umgroupssharesfindbyresourceid)                                                                                   | **Get** /um/groups/{groupId}/shares/{resourceId}                                                                       | Retrieve a group share                                                      |
| *UserManagementApi*       | [**UmGroupsSharesGet**](docs/api/UserManagementApi.md#umgroupssharesget)                                                                                                             | **Get** /um/groups/{groupId}/shares                                                                                    | List Group Shares                                                           |
| *UserManagementApi*       | [**UmGroupsSharesPost**](docs/api/UserManagementApi.md#umgroupssharespost)                                                                                                           | **Post** /um/groups/{groupId}/shares/{resourceId}                                                                      | Add a resource to a group                                                   |
| *UserManagementApi*       | [**UmGroupsSharesPut**](docs/api/UserManagementApi.md#umgroupssharesput)                                                                                                             | **Put** /um/groups/{groupId}/shares/{resourceId}                                                                       | Modify resource permissions of a group                                      |
| *UserManagementApi*       | [**UmGroupsUsersDelete**](docs/api/UserManagementApi.md#umgroupsusersdelete)                                                                                                         | **Delete** /um/groups/{groupId}/users/{userId}                                                                         | Remove a user from a group                                                  |
| *UserManagementApi*       | [**UmGroupsUsersGet**](docs/api/UserManagementApi.md#umgroupsusersget)                                                                                                               | **Get** /um/groups/{groupId}/users                                                                                     | List Group Members                                                          |
| *UserManagementApi*       | [**UmGroupsUsersPost**](docs/api/UserManagementApi.md#umgroupsuserspost)                                                                                                             | **Post** /um/groups/{groupId}/users                                                                                    | Add a user to a group                                                       |
| *UserManagementApi*       | [**UmResourcesFindByType**](docs/api/UserManagementApi.md#umresourcesfindbytype)                                                                                                     | **Get** /um/resources/{resourceType}                                                                                   | Retrieve a list of Resources by type.                                       |
| *UserManagementApi*       | [**UmResourcesFindByTypeAndId**](docs/api/UserManagementApi.md#umresourcesfindbytypeandid)                                                                                           | **Get** /um/resources/{resourceType}/{resourceId}                                                                      | Retrieve a Resource by type.                                                |
| *UserManagementApi*       | [**UmResourcesGet**](docs/api/UserManagementApi.md#umresourcesget)                                                                                                                   | **Get** /um/resources                                                                                                  | List All Resources.                                                         |
| *UserManagementApi*       | [**UmUsersDelete**](docs/api/UserManagementApi.md#umusersdelete)                                                                                                                     | **Delete** /um/users/{userId}                                                                                          | Delete a User                                                               |
| *UserManagementApi*       | [**UmUsersFindById**](docs/api/UserManagementApi.md#umusersfindbyid)                                                                                                                 | **Get** /um/users/{userId}                                                                                             | Retrieve a User                                                             |
| *UserManagementApi*       | [**UmUsersGet**](docs/api/UserManagementApi.md#umusersget)                                                                                                                           | **Get** /um/users                                                                                                      | List all Users                                                              |
| *UserManagementApi*       | [**UmUsersGroupsGet**](docs/api/UserManagementApi.md#umusersgroupsget)                                                                                                               | **Get** /um/users/{userId}/groups                                                                                      | Retrieve a User&#39;s group resources                                       |
| *UserManagementApi*       | [**UmUsersOwnsGet**](docs/api/UserManagementApi.md#umusersownsget)                                                                                                                   | **Get** /um/users/{userId}/owns                                                                                        | Retrieve a User&#39;s own resources                                         |
| *UserManagementApi*       | [**UmUsersPost**](docs/api/UserManagementApi.md#umuserspost)                                                                                                                         | **Post** /um/users                                                                                                     | Create a user                                                               |
| *UserManagementApi*       | [**UmUsersPut**](docs/api/UserManagementApi.md#umusersput)                                                                                                                           | **Put** /um/users/{userId}                                                                                             | Modify a user                                                               |
| *UserS3KeysApi*           | [**UmUsersS3keysDelete**](docs/api/UserS3KeysApi.md#umuserss3keysdelete)                                                                                                             | **Delete** /um/users/{userId}/s3keys/{keyId}                                                                           | Delete an S3 Key                                                            |
| *UserS3KeysApi*           | [**UmUsersS3keysFindByKeyId**](docs/api/UserS3KeysApi.md#umuserss3keysfindbykeyid)                                                                                                   | **Get** /um/users/{userId}/s3keys/{keyId}                                                                              | Retrieve given S3 Key belonging to the given User                           |
| *UserS3KeysApi*           | [**UmUsersS3keysGet**](docs/api/UserS3KeysApi.md#umuserss3keysget)                                                                                                                   | **Get** /um/users/{userId}/s3keys                                                                                      | Retrieve a User&#39;s S3 keys                                               |
| *UserS3KeysApi*           | [**UmUsersS3keysPost**](docs/api/UserS3KeysApi.md#umuserss3keyspost)                                                                                                                 | **Post** /um/users/{userId}/s3keys                                                                                     | Create a S3 Key for the given User                                          |
| *UserS3KeysApi*           | [**UmUsersS3keysPut**](docs/api/UserS3KeysApi.md#umuserss3keysput)                                                                                                                   | **Put** /um/users/{userId}/s3keys/{keyId}                                                                              | Modify a S3 key having the given key id                                     |
| *UserS3KeysApi*           | [**UmUsersS3ssourlGet**](docs/api/UserS3KeysApi.md#umuserss3ssourlget)                                                                                                               | **Get** /um/users/{userId}/s3ssourl                                                                                    | Retrieve S3 object storage single signon URL for the given user             |
| *VolumesApi*              | [**DatacentersVolumesCreateSnapshotPost**](docs/api/VolumesApi.md#datacentersvolumescreatesnapshotpost)                                                                              | **Post** /datacenters/{datacenterId}/volumes/{volumeId}/create-snapshot                                                | Create Volume Snapshot                                                      |
| *VolumesApi*              | [**DatacentersVolumesDelete**](docs/api/VolumesApi.md#datacentersvolumesdelete)                                                                                                      | **Delete** /datacenters/{datacenterId}/volumes/{volumeId}                                                              | Delete a Volume                                                             |
| *VolumesApi*              | [**DatacentersVolumesFindById**](docs/api/VolumesApi.md#datacentersvolumesfindbyid)                                                                                                  | **Get** /datacenters/{datacenterId}/volumes/{volumeId}                                                                 | Retrieve a Volume                                                           |
| *VolumesApi*              | [**DatacentersVolumesGet**](docs/api/VolumesApi.md#datacentersvolumesget)                                                                                                            | **Get** /datacenters/{datacenterId}/volumes                                                                            | List Volumes                                                                |
| *VolumesApi*              | [**DatacentersVolumesPatch**](docs/api/VolumesApi.md#datacentersvolumespatch)                                                                                                        | **Patch** /datacenters/{datacenterId}/volumes/{volumeId}                                                               | Partially modify a Volume                                                   |
| *VolumesApi*              | [**DatacentersVolumesPost**](docs/api/VolumesApi.md#datacentersvolumespost)                                                                                                          | **Post** /datacenters/{datacenterId}/volumes                                                                           | Create a Volume                                                             |
| *VolumesApi*              | [**DatacentersVolumesPut**](docs/api/VolumesApi.md#datacentersvolumesput)                                                                                                            | **Put** /datacenters/{datacenterId}/volumes/{volumeId}                                                                 | Modify a Volume                                                             |
| *VolumesApi*              | [**DatacentersVolumesRestoreSnapshotPost**](docs/api/VolumesApi.md#datacentersvolumesrestoresnapshotpost)                                                                            | **Post** /datacenters/{datacenterId}/volumes/{volumeId}/restore-snapshot                                               | Restore Volume Snapshot                                                     |
)
</details>

## Documentation For Models

All URIs are relative to *https://api.ionos.com/cloudapi/v6*
<details >
<summary title="Click to toggle">API models list</summary>

 - [AttachedVolumes](docs/models/AttachedVolumes.md)
 - [BackupUnit](docs/models/BackupUnit.md)
 - [BackupUnitProperties](docs/models/BackupUnitProperties.md)
 - [BackupUnitSSO](docs/models/BackupUnitSSO.md)
 - [BackupUnits](docs/models/BackupUnits.md)
 - [BalancedNics](docs/models/BalancedNics.md)
 - [Cdroms](docs/models/Cdroms.md)
 - [ConnectableDatacenter](docs/models/ConnectableDatacenter.md)
 - [Contract](docs/models/Contract.md)
 - [ContractProperties](docs/models/ContractProperties.md)
 - [Contracts](docs/models/Contracts.md)
 - [CpuArchitectureProperties](docs/models/CpuArchitectureProperties.md)
 - [DataCenterEntities](docs/models/DataCenterEntities.md)
 - [Datacenter](docs/models/Datacenter.md)
 - [DatacenterElementMetadata](docs/models/DatacenterElementMetadata.md)
 - [DatacenterProperties](docs/models/DatacenterProperties.md)
 - [Datacenters](docs/models/Datacenters.md)
 - [Error](docs/models/Error.md)
 - [ErrorMessage](docs/models/ErrorMessage.md)
 - [FirewallRule](docs/models/FirewallRule.md)
 - [FirewallRules](docs/models/FirewallRules.md)
 - [FirewallruleProperties](docs/models/FirewallruleProperties.md)
 - [FlowLog](docs/models/FlowLog.md)
 - [FlowLogProperties](docs/models/FlowLogProperties.md)
 - [FlowLogPut](docs/models/FlowLogPut.md)
 - [FlowLogs](docs/models/FlowLogs.md)
 - [Group](docs/models/Group.md)
 - [GroupEntities](docs/models/GroupEntities.md)
 - [GroupMembers](docs/models/GroupMembers.md)
 - [GroupProperties](docs/models/GroupProperties.md)
 - [GroupShare](docs/models/GroupShare.md)
 - [GroupShareProperties](docs/models/GroupShareProperties.md)
 - [GroupShares](docs/models/GroupShares.md)
 - [GroupUsers](docs/models/GroupUsers.md)
 - [Groups](docs/models/Groups.md)
 - [IPFailover](docs/models/IPFailover.md)
 - [Image](docs/models/Image.md)
 - [ImageProperties](docs/models/ImageProperties.md)
 - [Images](docs/models/Images.md)
 - [Info](docs/models/Info.md)
 - [IpBlock](docs/models/IpBlock.md)
 - [IpBlockProperties](docs/models/IpBlockProperties.md)
 - [IpBlocks](docs/models/IpBlocks.md)
 - [IpConsumer](docs/models/IpConsumer.md)
 - [KubernetesAutoScaling](docs/models/KubernetesAutoScaling.md)
 - [KubernetesCluster](docs/models/KubernetesCluster.md)
 - [KubernetesClusterEntities](docs/models/KubernetesClusterEntities.md)
 - [KubernetesClusterForPost](docs/models/KubernetesClusterForPost.md)
 - [KubernetesClusterForPut](docs/models/KubernetesClusterForPut.md)
 - [KubernetesClusterProperties](docs/models/KubernetesClusterProperties.md)
 - [KubernetesClusterPropertiesForPost](docs/models/KubernetesClusterPropertiesForPost.md)
 - [KubernetesClusterPropertiesForPut](docs/models/KubernetesClusterPropertiesForPut.md)
 - [KubernetesClusters](docs/models/KubernetesClusters.md)
 - [KubernetesMaintenanceWindow](docs/models/KubernetesMaintenanceWindow.md)
 - [KubernetesNode](docs/models/KubernetesNode.md)
 - [KubernetesNodeMetadata](docs/models/KubernetesNodeMetadata.md)
 - [KubernetesNodePool](docs/models/KubernetesNodePool.md)
 - [KubernetesNodePoolForPost](docs/models/KubernetesNodePoolForPost.md)
 - [KubernetesNodePoolForPut](docs/models/KubernetesNodePoolForPut.md)
 - [KubernetesNodePoolLan](docs/models/KubernetesNodePoolLan.md)
 - [KubernetesNodePoolLanRoutes](docs/models/KubernetesNodePoolLanRoutes.md)
 - [KubernetesNodePoolProperties](docs/models/KubernetesNodePoolProperties.md)
 - [KubernetesNodePoolPropertiesForPost](docs/models/KubernetesNodePoolPropertiesForPost.md)
 - [KubernetesNodePoolPropertiesForPut](docs/models/KubernetesNodePoolPropertiesForPut.md)
 - [KubernetesNodePools](docs/models/KubernetesNodePools.md)
 - [KubernetesNodeProperties](docs/models/KubernetesNodeProperties.md)
 - [KubernetesNodes](docs/models/KubernetesNodes.md)
 - [Label](docs/models/Label.md)
 - [LabelProperties](docs/models/LabelProperties.md)
 - [LabelResource](docs/models/LabelResource.md)
 - [LabelResourceProperties](docs/models/LabelResourceProperties.md)
 - [LabelResources](docs/models/LabelResources.md)
 - [Labels](docs/models/Labels.md)
 - [Lan](docs/models/Lan.md)
 - [LanEntities](docs/models/LanEntities.md)
 - [LanNics](docs/models/LanNics.md)
 - [LanPost](docs/models/LanPost.md)
 - [LanProperties](docs/models/LanProperties.md)
 - [LanPropertiesPost](docs/models/LanPropertiesPost.md)
 - [Lans](docs/models/Lans.md)
 - [Loadbalancer](docs/models/Loadbalancer.md)
 - [LoadbalancerEntities](docs/models/LoadbalancerEntities.md)
 - [LoadbalancerProperties](docs/models/LoadbalancerProperties.md)
 - [Loadbalancers](docs/models/Loadbalancers.md)
 - [Location](docs/models/Location.md)
 - [LocationProperties](docs/models/LocationProperties.md)
 - [Locations](docs/models/Locations.md)
 - [NatGateway](docs/models/NatGateway.md)
 - [NatGatewayEntities](docs/models/NatGatewayEntities.md)
 - [NatGatewayLanProperties](docs/models/NatGatewayLanProperties.md)
 - [NatGatewayProperties](docs/models/NatGatewayProperties.md)
 - [NatGatewayPut](docs/models/NatGatewayPut.md)
 - [NatGatewayRule](docs/models/NatGatewayRule.md)
 - [NatGatewayRuleProperties](docs/models/NatGatewayRuleProperties.md)
 - [NatGatewayRuleProtocol](docs/models/NatGatewayRuleProtocol.md)
 - [NatGatewayRulePut](docs/models/NatGatewayRulePut.md)
 - [NatGatewayRuleType](docs/models/NatGatewayRuleType.md)
 - [NatGatewayRules](docs/models/NatGatewayRules.md)
 - [NatGateways](docs/models/NatGateways.md)
 - [NetworkLoadBalancer](docs/models/NetworkLoadBalancer.md)
 - [NetworkLoadBalancerEntities](docs/models/NetworkLoadBalancerEntities.md)
 - [NetworkLoadBalancerForwardingRule](docs/models/NetworkLoadBalancerForwardingRule.md)
 - [NetworkLoadBalancerForwardingRuleHealthCheck](docs/models/NetworkLoadBalancerForwardingRuleHealthCheck.md)
 - [NetworkLoadBalancerForwardingRuleProperties](docs/models/NetworkLoadBalancerForwardingRuleProperties.md)
 - [NetworkLoadBalancerForwardingRulePut](docs/models/NetworkLoadBalancerForwardingRulePut.md)
 - [NetworkLoadBalancerForwardingRuleTarget](docs/models/NetworkLoadBalancerForwardingRuleTarget.md)
 - [NetworkLoadBalancerForwardingRuleTargetHealthCheck](docs/models/NetworkLoadBalancerForwardingRuleTargetHealthCheck.md)
 - [NetworkLoadBalancerForwardingRules](docs/models/NetworkLoadBalancerForwardingRules.md)
 - [NetworkLoadBalancerProperties](docs/models/NetworkLoadBalancerProperties.md)
 - [NetworkLoadBalancerPut](docs/models/NetworkLoadBalancerPut.md)
 - [NetworkLoadBalancers](docs/models/NetworkLoadBalancers.md)
 - [Nic](docs/models/Nic.md)
 - [NicEntities](docs/models/NicEntities.md)
 - [NicProperties](docs/models/NicProperties.md)
 - [NicPut](docs/models/NicPut.md)
 - [Nics](docs/models/Nics.md)
 - [NoStateMetaData](docs/models/NoStateMetaData.md)
 - [PaginationLinks](docs/models/PaginationLinks.md)
 - [Peer](docs/models/Peer.md)
 - [PrivateCrossConnect](docs/models/PrivateCrossConnect.md)
 - [PrivateCrossConnectProperties](docs/models/PrivateCrossConnectProperties.md)
 - [PrivateCrossConnects](docs/models/PrivateCrossConnects.md)
 - [RemoteConsoleUrl](docs/models/RemoteConsoleUrl.md)
 - [Request](docs/models/Request.md)
 - [RequestMetadata](docs/models/RequestMetadata.md)
 - [RequestProperties](docs/models/RequestProperties.md)
 - [RequestStatus](docs/models/RequestStatus.md)
 - [RequestStatusMetadata](docs/models/RequestStatusMetadata.md)
 - [RequestTarget](docs/models/RequestTarget.md)
 - [Requests](docs/models/Requests.md)
 - [Resource](docs/models/Resource.md)
 - [ResourceEntities](docs/models/ResourceEntities.md)
 - [ResourceGroups](docs/models/ResourceGroups.md)
 - [ResourceLimits](docs/models/ResourceLimits.md)
 - [ResourceProperties](docs/models/ResourceProperties.md)
 - [ResourceReference](docs/models/ResourceReference.md)
 - [Resources](docs/models/Resources.md)
 - [ResourcesUsers](docs/models/ResourcesUsers.md)
 - [S3Key](docs/models/S3Key.md)
 - [S3KeyMetadata](docs/models/S3KeyMetadata.md)
 - [S3KeyProperties](docs/models/S3KeyProperties.md)
 - [S3Keys](docs/models/S3Keys.md)
 - [S3ObjectStorageSSO](docs/models/S3ObjectStorageSSO.md)
 - [Server](docs/models/Server.md)
 - [ServerEntities](docs/models/ServerEntities.md)
 - [ServerProperties](docs/models/ServerProperties.md)
 - [Servers](docs/models/Servers.md)
 - [Snapshot](docs/models/Snapshot.md)
 - [SnapshotProperties](docs/models/SnapshotProperties.md)
 - [Snapshots](docs/models/Snapshots.md)
 - [TargetPortRange](docs/models/TargetPortRange.md)
 - [Template](docs/models/Template.md)
 - [TemplateProperties](docs/models/TemplateProperties.md)
 - [Templates](docs/models/Templates.md)
 - [Token](docs/models/Token.md)
 - [Type](docs/models/Type.md)
 - [User](docs/models/User.md)
 - [UserMetadata](docs/models/UserMetadata.md)
 - [UserPost](docs/models/UserPost.md)
 - [UserProperties](docs/models/UserProperties.md)
 - [UserPropertiesPost](docs/models/UserPropertiesPost.md)
 - [UserPropertiesPut](docs/models/UserPropertiesPut.md)
 - [UserPut](docs/models/UserPut.md)
 - [Users](docs/models/Users.md)
 - [UsersEntities](docs/models/UsersEntities.md)
 - [Volume](docs/models/Volume.md)
 - [VolumeProperties](docs/models/VolumeProperties.md)
 - [Volumes](docs/models/Volumes.md)
</details>

## Documentation For Authorization



### Basic Authentication

- **Type**: HTTP basic authentication

Example

```golang
auth := context.WithValue(context.Background(), sw.ContextBasicAuth, sw.BasicAuth{
    UserName: "username",
    Password: "password",
})
r, err := client.Service.Operation(auth, args)
```


### Token Authentication

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header

Note, each API key must be added to a map of `map[string]APIKey` where the key is: Authorization and passed in as the auth context for each request.


## Documentation for Utility Methods

Due to the fact that model structure members are all pointers, this package contains
a number of utility functions to easily obtain pointers to values of basic types.
Each of these functions takes a value of the given basic type and returns a pointer to it:

* `PtrBool`
* `PtrInt`
* `PtrInt32`
* `PtrInt64`
* `PtrFloat`
* `PtrFloat32`
* `PtrFloat64`
* `PtrString`
* `PtrTime`

## Author

## Debugging

If you want to see the API call request and response messages, you need to set the Debug field in the Configuration struct:

```golang
package main
import "github.com/ionos-cloud/sdk-go/v5"
func main() {
    // create your configuration. replace username, password, token and url with correct values, or use NewConfigurationFromEnv()
    // if you have set your env variables as explained above
    cfg := ionoscloud.NewConfiguration("username", "password", "token", "hostUrl")
    // enable request and response logging
    cfg.Debug = true
    // create you api client with the configuration
    apiClient := ionoscloud.NewAPIClient(cfg)
}
```

⚠️ **_Note: We recommend you only set this field for debugging purposes. Disable it in your production environments because it can log sensitive data. It logs the full request and response without encryption, even for an HTTPS call. Verbose request and response logging can also significantly impact your application's performance._**

